@@ -30,6 +30,9 @@
 /* Define as rpl_getgroups if getgroups doesn't work right.  */
 #undef getgroups
 
+/* Define to gnu_strftime if the replacement function should be used.  */
+#undef strftime
+
 /* Define if your system defines TIOCGWINSZ in sys/ioctl.h.  */
 #undef GWINSZ_IN_SYS_IOCTL
 
