@@ -1,5 +1,5 @@
 /* fsusage.c -- return space usage of mounted filesystems
-   Copyright (C) 1991, 1992 Free Software Foundation, Inc.
+   Copyright (C) 1991, 1992, 1996 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,11 +12,11 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if HAVE_CONFIG_H
+# include <config.h>
 #endif
 
 #include <sys/types.h>
@@ -25,36 +25,40 @@
 
 int statfs ();
 
-#ifdef HAVE_SYS_PARAM_H
-#include <sys/param.h>
+#if HAVE_SYS_PARAM_H
+# include <sys/param.h>
 #endif
 
-#ifdef HAVE_SYS_MOUNT_H
-#include <sys/mount.h>
+#if HAVE_SYS_MOUNT_H
+# include <sys/mount.h>
 #endif
 
-#ifdef HAVE_SYS_VFS_H
-#include <sys/vfs.h>
+#if HAVE_SYS_VFS_H
+# include <sys/vfs.h>
 #endif
 
-#if defined(HAVE_SYS_FILSYS_H) && !defined(_CRAY)
-#include <sys/filsys.h>		/* SVR2.  */
+#if HAVE_SYS_FS_S5PARAM_H	/* Fujitsu UXP/V */
+# include <sys/fs/s5param.h>
 #endif
 
-#ifdef HAVE_FCNTL_H
-#include <fcntl.h>
+#if defined (HAVE_SYS_FILSYS_H) && !defined (_CRAY)
+# include <sys/filsys.h>	/* SVR2 */
 #endif
 
-#ifdef HAVE_SYS_STATFS_H
-#include <sys/statfs.h>
+#if HAVE_FCNTL_H
+# include <fcntl.h>
 #endif
 
-#ifdef HAVE_DUSTAT_H		/* AIX PS/2.  */
-#include <sys/dustat.h>
+#if HAVE_SYS_STATFS_H
+# include <sys/statfs.h>
 #endif
 
-#ifdef HAVE_SYS_STATVFS_H	/* SVR4.  */
-#include <sys/statvfs.h>
+#if HAVE_DUSTAT_H		/* AIX PS/2 */
+# include <sys/dustat.h>
+#endif
+
+#if HAVE_SYS_STATVFS_H		/* SVR4 */
+# include <sys/statvfs.h>
 int statvfs ();
 #endif
 
@@ -74,11 +78,11 @@ adjust_blocks (blocks, fromsize, tosize)
   if (fromsize <= 0)
     return -1;
 
-  if (fromsize == tosize)	/* E.g., from 512 to 512.  */
+  if (fromsize == tosize)	/* e.g., from 512 to 512 */
     return blocks;
-  else if (fromsize > tosize)	/* E.g., from 2048 to 512.  */
+  else if (fromsize > tosize)	/* e.g., from 2048 to 512 */
     return blocks * (fromsize / tosize);
-  else				/* E.g., from 256 to 512.  */
+  else				/* e.g., from 256 to 512 */
     return (blocks + (blocks < 0 ? -1 : 1)) / (tosize / fromsize);
 }
 
@@ -86,42 +90,56 @@ adjust_blocks (blocks, fromsize, tosize)
    the filesystem on which PATH resides.
    DISK is the device on which PATH is mounted, for space-getting
    methods that need to know it.
-   Return 0 if successful, -1 if not. */
-
+   Return 0 if successful, -1 if not.  When returning -1, ensure that
+   ERRNO is either a system error value, or zero if DISK is NULL
+   on a system that requires a non-NULL value.  */
 int
 get_fs_usage (path, disk, fsp)
      const char *path;
      const char *disk;
      struct fs_usage *fsp;
 {
-#if defined (STAT_STATFS3_OSF1)
+#ifdef STAT_STATFS3_OSF1
+# define CONVERT_BLOCKS(B) adjust_blocks ((B), fsd.f_fsize, 512)
+
   struct statfs fsd;
 
   if (statfs (path, &fsd, sizeof (struct statfs)) != 0)
     return -1;
-#define CONVERT_BLOCKS(b) adjust_blocks ((b), fsd.f_fsize, 512)
+
 #endif /* STAT_STATFS3_OSF1 */
 
-#ifdef STAT_STATFS2_FS_DATA	/* Ultrix.  */
+#ifdef STAT_STATFS2_FS_DATA	/* Ultrix */
+# define CONVERT_BLOCKS(B) adjust_blocks ((B), 1024, 512)
+
   struct fs_data fsd;
 
   if (statfs (path, &fsd) != 1)
     return -1;
-#define CONVERT_BLOCKS(b) adjust_blocks ((b), 1024, 512)
   fsp->fsu_blocks = CONVERT_BLOCKS (fsd.fd_req.btot);
   fsp->fsu_bfree = CONVERT_BLOCKS (fsd.fd_req.bfree);
   fsp->fsu_bavail = CONVERT_BLOCKS (fsd.fd_req.bfreen);
   fsp->fsu_files = fsd.fd_req.gtot;
   fsp->fsu_ffree = fsd.fd_req.gfree;
-#endif
 
-#ifdef STAT_READ_FILSYS		/* SVR2.  */
-#ifndef SUPERBOFF
-#define SUPERBOFF (SUPERB * 512)
-#endif
+#endif /* STAT_STATFS2_FS_DATA */
+
+#ifdef STAT_READ_FILSYS		/* SVR2 */
+# ifndef SUPERBOFF
+#  define SUPERBOFF (SUPERB * 512)
+# endif
+# define CONVERT_BLOCKS(B) \
+    adjust_blocks ((B), (fsd.s_type == Fs2b ? 1024 : 512), 512)
+
   struct filsys fsd;
   int fd;
 
+  if (! disk)
+    {
+      errno = 0;
+      return -1;
+    }
+
   fd = open (disk, O_RDONLY);
   if (fd < 0)
     return -1;
@@ -132,21 +150,24 @@ get_fs_usage (path, disk, fsp)
       return -1;
     }
   close (fd);
-#define CONVERT_BLOCKS(b) adjust_blocks ((b), (fsd.s_type == Fs2b ? 1024 : 512), 512)
   fsp->fsu_blocks = CONVERT_BLOCKS (fsd.s_fsize);
   fsp->fsu_bfree = CONVERT_BLOCKS (fsd.s_tfree);
   fsp->fsu_bavail = CONVERT_BLOCKS (fsd.s_tfree);
   fsp->fsu_files = (fsd.s_isize - 2) * INOPB * (fsd.s_type == Fs2b ? 2 : 1);
   fsp->fsu_ffree = fsd.s_tinode;
-#endif
 
-#ifdef STAT_STATFS2_BSIZE	/* 4.3BSD, SunOS 4, HP-UX, AIX.  */
+#endif /* STAT_READ_FILSYS */
+
+#ifdef STAT_STATFS2_BSIZE	/* 4.3BSD, SunOS 4, HP-UX, AIX */
+# define CONVERT_BLOCKS(B) adjust_blocks ((B), fsd.f_bsize, 512)
+
   struct statfs fsd;
 
   if (statfs (path, &fsd) < 0)
     return -1;
 
-#ifdef STATFS_TRUNCATES_BLOCK_COUNTS
+# ifdef STATFS_TRUNCATES_BLOCK_COUNTS
+
   /* In SunOS 4.1.2, 4.1.3, and 4.1.3_U1, the block counts in the
      struct statfs are truncated to 2GB.  These conditions detect that
      truncation, presumably without botching the 4.1.1 case, in which
@@ -158,20 +179,35 @@ get_fs_usage (path, disk, fsp)
       fsd.f_bfree = fsd.f_spare[1];
       fsd.f_bavail = fsd.f_spare[2];
     }
-#endif /* STATFS_TRUNCATES_BLOCK_COUNTS */
+# endif /* STATFS_TRUNCATES_BLOCK_COUNTS */
 
-#define CONVERT_BLOCKS(b) adjust_blocks ((b), fsd.f_bsize, 512)
-#endif
+#endif /* STAT_STATFS2_BSIZE */
+
+#ifdef STAT_STATFS2_FSIZE	/* 4.4BSD */
+# define CONVERT_BLOCKS(B) adjust_blocks ((B), fsd.f_fsize, 512)
 
-#ifdef STAT_STATFS2_FSIZE	/* 4.4BSD.  */
   struct statfs fsd;
 
   if (statfs (path, &fsd) < 0)
     return -1;
-#define CONVERT_BLOCKS(b) adjust_blocks ((b), fsd.f_fsize, 512)
-#endif
 
-#ifdef STAT_STATFS4		/* SVR3, Dynix, Irix, AIX.  */
+#endif /* STAT_STATFS2_FSIZE */
+
+#ifdef STAT_STATFS4		/* SVR3, Dynix, Irix, AIX */
+# if _AIX || defined(_CRAY)
+#  define CONVERT_BLOCKS(B) adjust_blocks ((B), fsd.f_bsize, 512)
+#  ifdef _CRAY
+#   define f_bavail f_bfree
+#  endif
+# else
+#  define CONVERT_BLOCKS(B) (B)
+#  ifndef _SEQUENT_		/* _SEQUENT_ is DYNIX/ptx */
+#   ifndef DOLPHIN		/* DOLPHIN 3.8.alfa/7.18 has f_bavail */
+#    define f_bavail f_bfree
+#   endif
+#  endif
+# endif
+
   struct statfs fsd;
 
   if (statfs (path, &fsd, sizeof fsd, 0) < 0)
@@ -179,35 +215,31 @@ get_fs_usage (path, disk, fsp)
   /* Empirically, the block counts on most SVR3 and SVR3-derived
      systems seem to always be in terms of 512-byte blocks,
      no matter what value f_bsize has.  */
-# if _AIX
-#  define CONVERT_BLOCKS(b) adjust_blocks ((b), fsd.f_bsize, 512)
-# else
-#  define CONVERT_BLOCKS(b) (b)
-#  ifndef _SEQUENT_		/* _SEQUENT_ is DYNIX/ptx.  */
-#   ifndef DOLPHIN		/* DOLPHIN 3.8.alfa/7.18 has f_bavail */
-#    define f_bavail f_bfree
-#   endif
-#  endif
-# endif
-#endif
 
-#ifdef STAT_STATVFS		/* SVR4.  */
+#endif /* STAT_STATFS4 */
+
+#ifdef STAT_STATVFS		/* SVR4 */
+# define CONVERT_BLOCKS(B) \
+    adjust_blocks ((B), fsd.f_frsize ? fsd.f_frsize : fsd.f_bsize, 512)
+
   struct statvfs fsd;
 
   if (statvfs (path, &fsd) < 0)
     return -1;
   /* f_frsize isn't guaranteed to be supported.  */
-#define CONVERT_BLOCKS(b) \
-  adjust_blocks ((b), fsd.f_frsize ? fsd.f_frsize : fsd.f_bsize, 512)
-#endif
 
-#if !defined(STAT_STATFS2_FS_DATA) && !defined(STAT_READ_FILSYS) /* !Ultrix && !SVR2.  */
+#endif /* STAT_STATVFS */
+
+#if !defined(STAT_STATFS2_FS_DATA) && !defined(STAT_READ_FILSYS)
+				/* !Ultrix && !SVR2 */
+
   fsp->fsu_blocks = CONVERT_BLOCKS (fsd.f_blocks);
   fsp->fsu_bfree = CONVERT_BLOCKS (fsd.f_bfree);
   fsp->fsu_bavail = CONVERT_BLOCKS (fsd.f_bavail);
   fsp->fsu_files = fsd.f_files;
   fsp->fsu_ffree = fsd.f_ffree;
-#endif
+
+#endif /* not STAT_STATFS2_FS_DATA && not STAT_READ_FILSYS */
 
   return 0;
 }
@@ -238,4 +270,5 @@ statfs (path, fsb)
   fsb->f_fsid.val[1] = fsd.du_pckno;
   return 0;
 }
+
 #endif /* _AIX && _I386 */
