@@ -133,7 +133,12 @@ change_file_mode (const char *file, const struct mode_change *changes,
     {
       if (verbose)
 	describe_change (file, newmode, 1);
-      if (chmod (file, (int) newmode))
+      if (chmod (file, (int) newmode) == 0)
+	{
+	  if (changes_only)
+	    describe_change (file, newmode, 1);
+	}
+      else
 	{
 	  if (force_silent == 0)
 	    error (0, errno, "%s", file);
@@ -224,7 +229,9 @@ Usage: %s [OPTION]... MODE[,MODE]... FILE...\n\
       --version           output version information and exit\n\
 \n\
 Each MODE is one or more of the letters ugoa, one of the symbols +-= and\n\
-one or more of the letters rwxXstugo.\n"));
+one or more of the letters rwxXstugo.\n\
+"));
+      puts (_("\nReport bugs to fileutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status);
 }
@@ -283,7 +290,6 @@ main (int argc, char **argv)
 	  recurse = 1;
 	  break;
 	case 'c':
-	  verbose = 1;
 	  changes_only = 1;
 	  break;
 	case 'f':
@@ -299,7 +305,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("chmod - %s\n", PACKAGE_VERSION);
+      printf ("chmod (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (0);
     }
 
