@@ -243,13 +243,15 @@ Change the owner and/or group of each FILE to OWNER and/or GROUP.\n\
   -h, --no-dereference   affect symbolic links instead of any referenced file\n\
                          (available only on systems with lchown system call)\n\
   -f, --silent, --quiet  suppress most error messages\n\
+  -R, --recursive        operate on files and directories recursively\n\
   -v, --verbose          explain what is being done\n\
-  -R, --recursive        change files and directories recursively\n\
       --help             display this help and exit\n\
       --version          output version information and exit\n\
 \n\
 Owner is unchanged if missing.  Group is unchanged if missing, but changed\n\
-to login group if implied by a period.  A colon may replace the period.\n"));
+to login group if implied by a period.  A colon may replace the period.\n\
+"));
+      puts (_("\nReport bugs to fileutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status);
 }
@@ -300,7 +302,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("chown - %s\n", PACKAGE_VERSION);
+      printf ("chown (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (0);
     }
 
