@@ -339,7 +339,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("dd - %s\n", PACKAGE_VERSION);
+      printf ("dd (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (0);
     }
 
@@ -1116,7 +1116,9 @@ by w for x2, by b for x512, by k for x1024.  Each KEYWORD may be:\n\
   ucase     change lower case to upper case\n\
   swab      swap every pair of input bytes\n\
   noerror   continue after read errors\n\
-  sync      pad every input block with NULs to ibs-size\n"));
+  sync      pad every input block with NULs to ibs-size\n\
+"));
+      puts (_("\nReport bugs to fileutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status);
 }
