@@ -27,10 +27,14 @@
 #include "mountlist.h"
 #include "fsusage.h"
 #include "system.h"
+#include "save-cwd.h"
 #include "error.h"
 
+char *dirname ();
+void strip_trailing_slashes ();
 char *xmalloc ();
 char *xstrdup ();
+char *xgetcwd ();
 
 /* The maximum length of a human-readable string.  Be pessimistic
    and assume `int' is 64-bits wide.  Converting 2^63 - 1 gives the
@@ -237,7 +241,9 @@ excluded_fstype (const char *fstype)
 /* Display a space listing for the disk device with absolute path DISK.
    If MOUNT_POINT is non-NULL, it is the path of the root of the
    filesystem on DISK.
-   If FSTYPE is non-NULL, it is the type of the filesystem on DISK. */
+   If FSTYPE is non-NULL, it is the type of the filesystem on DISK.
+   If MOUNT_POINT is non-NULL, then DISK may be NULL -- certain systems may
+   not be able to produce statistics in this case.  */
 
 static void
 show_dev (const char *disk, const char *mount_point, const char *fstype)
@@ -302,10 +308,15 @@ show_dev (const char *disk, const char *mount_point, const char *fstype)
 	(inodes_used * 100.0 / fsu.fsu_files + 0.5);
     }
 
+  if (! disk)
+    disk = "-";			/* unknown */
+
   printf ((print_type ? "%-13s" : "%-20s"), disk);
-  if (strlen (disk) > (print_type ? 13 : 20) && !posix_format)
+  if ((int) strlen (disk) > (print_type ? 13 : 20) && !posix_format)
     printf ((print_type ? "\n%13s" : "\n%20s"), "");
 
+  if (! fstype)
+    fstype = "-";		/* unknown */
   if (print_type)
     printf (" %-5s ", fstype);
 
@@ -362,10 +373,80 @@ show_disk (const char *disk)
   show_dev (disk, (char *) NULL, (char *) NULL);
 }
 
+/* Return the root mountpoint of the filesystem on which FILE exists, in
+   malloced storage.  FILE_STAT should be the result of stating FILE.  */
+static char *
+find_mount_point (const char *file, const struct stat *file_stat)
+{
+  struct saved_cwd cwd;
+  struct stat last_stat;
+  char *mp = 0;			/* The malloced mount point path.  */
+
+  if (save_cwd (&cwd))
+    return NULL;
+
+  if (S_ISDIR (file_stat->st_mode))
+    /* FILE is a directory, so just chdir there directly.  */
+    {
+      last_stat = *file_stat;
+      if (chdir (file) < 0)
+	return NULL;
+    }
+  else
+    /* FILE is some other kind of file, we need to use its directory.  */
+    {
+      int rv;
+      char *tmp = xstrdup (file);
+      char *dir;
+
+      strip_trailing_slashes (tmp);
+      dir = dirname (tmp);
+      free (tmp);
+      rv = chdir (dir);
+      free (dir);
+
+      if (rv < 0)
+	return NULL;
+
+      if (stat (".", &last_stat) < 0)
+	goto done;
+    }
+
+  /* Now walk up FILE's parents until we find another filesystem or /,
+     chdiring as we go.  LAST_STAT holds stat information for the last place
+     we visited.  */
+  for (;;)
+    {
+      struct stat st;
+      if (stat ("..", &st) < 0)
+	goto done;
+      if (st.st_dev != last_stat.st_dev || st.st_ino == last_stat.st_ino)
+	/* cwd is the mount point.  */
+	break;
+      if (chdir ("..") < 0)
+	goto done;
+      last_stat = st;
+    }
+
+  /* Finally reached a mount point, see what it's called.  */
+  mp = xgetcwd ();
+
+done:
+  /* Restore the original cwd.  */
+  {
+    int save_errno = errno;
+    if (restore_cwd (&cwd, 0, mp))
+      exit (1);			/* We're scrod.  */
+    free_cwd (&cwd);
+    errno = save_errno;
+  }
+
+  return mp;
+}
+
 /* Figure out which device file or directory POINT is mounted on
    and show its disk usage.
    STATP is the results of `stat' on POINT.  */
-
 static void
 show_point (const char *point, const struct stat *statp)
 {
@@ -397,8 +478,21 @@ show_point (const char *point, const struct stat *statp)
 	  return;
 	}
     }
-  error (0, 0, _("cannot find mount point for %s"), point);
-  exit_status = 1;
+
+  /* We couldn't find the mount entry corresponding to POINT.  Go ahead and
+     print as much info as we can; methods that require the device to be
+     present will fail at a later point.  */
+  {
+    /* Find the actual mount point.  */
+    char *mp = find_mount_point (point, statp);
+    if (mp)
+      {
+	show_dev (0, mp, 0);
+	free (mp);
+      }
+    else
+      error (0, errno, "%s", point);
+  }
 }
 
 /* Determine what kind of node PATH is and show the disk usage
@@ -465,19 +559,21 @@ Show information about the filesystem on which each FILE resides,\n\
 or all filesystems by default.\n\
 \n\
   -a, --all             include filesystems having 0 blocks\n\
-  -h, --human-readable  print sizes in human readable format (e.g. 1K 234M 2G)\n\
+  -h, --human-readable  print sizes in human readable format (e.g., 1K 234M 2G)\n\
   -i, --inodes          list inode information instead of block usage\n\
   -k, --kilobytes       use 1024-byte blocks, not 512 despite POSIXLY_CORRECT\n\
   -m, --megabytes       use 1024K-byte blocks, not 512 despite POSIXLY_CORRECT\n\
       --no-sync         do not invoke sync before getting usage info (default)\n\
+  -P, --portability     use the POSIX output format\n\
       --sync            invoke sync before getting usage info\n\
   -t, --type=TYPE       limit listing to filesystems of type TYPE\n\
+  -T, --print-type      print filesystem type\n\
   -x, --exclude-type=TYPE   limit listing to filesystems not of type TYPE\n\
   -v                    (ignored)\n\
-  -P, --portability     use the POSIX output format\n\
-  -T, --print-type      print filesystem type\n\
       --help            display this help and exit\n\
-      --version         output version information and exit\n"));
+      --version         output version information and exit\n\
+"));
+      puts (_("\nReport bugs to fileutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status);
 }
@@ -514,7 +610,7 @@ main (int argc, char **argv)
   posix_format = 0;
   exit_status = 0;
 
-  while ((i = getopt_long (argc, argv, "aihkmPTt:vx:", long_options, NULL))
+  while ((i = getopt_long (argc, argv, "aiF:hkmPTt:vx:", long_options, NULL))
 	 != EOF)
     {
       switch (i)
@@ -554,9 +650,13 @@ main (int argc, char **argv)
 	case 130:
 	  require_sync = 0;
 	  break;
+
+	case 'F':
+	  /* Accept -F as a synonym for -t for compatibility with Solaris.  */
 	case 't':
 	  add_fs_type (optarg);
 	  break;
+
 	case 'v':		/* For SysV compatibility. */
 	  /* ignore */
 	  break;
@@ -570,7 +670,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("df - %s\n", PACKAGE_VERSION);
+      printf ("df (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (0);
     }
 
@@ -637,20 +737,22 @@ with the portable output format"));
 			   || print_type),
 			  show_all_fs);
 
-  if (mount_list == NULL)
-    error (1, errno, _("cannot read table of mounted filesystems"));
-
-  print_header ();
   if (require_sync)
     sync ();
 
   if (optind == argc)
-    show_all_entries ();
+    {
+      if (mount_list == NULL)
+	error (1, errno, _("cannot read table of mounted filesystems"));
+      print_header ();
+      show_all_entries ();
+    }
   else
     {
       /* Display explicitly requested empty filesystems. */
       show_listed_fs = 1;
 
+      print_header ();
       for (i = optind; i < argc; ++i)
 	if (argv[i])
 	  show_entry (argv[i], &stats[i - optind]);
