@@ -15,17 +15,17 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-/* If the macro MULTI_COL is defined,
+/* If ls_mode is LS_MULTI_COL,
    the multi-column format is the default regardless
    of the type of output device.
    This is for the `dir' program.
 
-   If the macro LONG_FORMAT is defined,
+   If ls_mode is LS_LONG_FORMAT,
    the long format is the default regardless of the
    type of output device.
    This is for the `vdir' program.
 
-   If neither is defined,
+   If ls_mode is LS_LS,
    the output format depends on whether the output
    device is a terminal.
    This is for the `ls' program. */
@@ -131,7 +131,6 @@ struct bin_str
   };
 
 #ifndef STDC_HEADERS
-char *ctime ();
 time_t time ();
 void free ();
 #endif
@@ -194,6 +193,7 @@ static void print_long_format __P ((const struct fileinfo *f));
 static void print_many_per_line __P ((void));
 static void print_name_with_quoting __P ((const char *p, unsigned int mode,
 					  int linkok));
+static void prep_non_filename_text __P ((void));
 static void print_type_indicator __P ((unsigned int mode));
 static void print_with_commas __P ((void));
 static void queue_directory __P ((const char *name, const char *realname));
@@ -673,7 +673,10 @@ main (int argc, char **argv)
     usage (EXIT_SUCCESS);
 
   if (print_with_color)
-    parse_ls_color ();
+    {
+      parse_ls_color ();
+      prep_non_filename_text ();
+    }
 
   format_needs_stat = sort_type == sort_time || sort_type == sort_size
     || format == long_format
@@ -743,6 +746,13 @@ main (int argc, char **argv)
   if (fclose (stdout) == EOF)
     error (EXIT_FAILURE, errno, _("write error"));
 
+  /* Restore default color before exiting */
+  if (print_with_color)
+    {
+      put_indicator (&color_indicator[C_LEFT]);
+      put_indicator (&color_indicator[C_RIGHT]);
+    }
+
   exit (exit_status);
 }
 
@@ -1285,7 +1295,7 @@ get_funky_string (char **dest, const char **src, int equals_end)
 	      *(q++) = *(p++) & 037;
 	      ++count;
 	    }
-	  else if ( *p == '?' )
+	  else if ( *p == '?')
 	    {
 	      *(q++) = 127;
 	      ++count;
@@ -1630,7 +1640,7 @@ gobble_file (const char *name, int explicit_arg, const char *dirname)
 
 #ifdef S_ISLNK
       if (S_ISLNK (files[files_index].stat.st_mode)
-	  && (explicit_arg || format == long_format))
+	  && (explicit_arg || format == long_format || print_with_color))
 	{
 	  char *linkpath;
 	  struct stat linkstats;
@@ -1642,9 +1652,12 @@ gobble_file (const char *name, int explicit_arg, const char *dirname)
 	     they won't be traced and when no indicator is needed. */
 	  if (linkpath
 	      && ((explicit_arg && format != long_format)
-		  || indicator_style != none)
+		  || indicator_style != none
+		  || print_with_color)
 	      && stat (linkpath, &linkstats) == 0)
 	    {
+	      files[files_index].linkok = 1;
+
 	      /* Symbolic links to directories that are mentioned on the
 	         command line are automatically traced if not being
 	         listed as files.  */
@@ -2021,18 +2034,20 @@ print_current_files (void)
 static void
 print_long_format (const struct fileinfo *f)
 {
-  char modebuf[20];
-#define TIMEBUF_SIZE 40
-  char timebuf[TIMEBUF_SIZE];
+  char modebuf[11];
 
   /* 7 fields that may (worst case: 64-bit integral values) require 20 bytes,
-     1 10-character mode string,
-     1 24-character time string,
-     9 spaces, one following each of these fields,
-     and 1 trailing NUL byte.  */
-  char bigbuf[7 * 20 + 10 + 24 + 9 + 1];
+     1 10-byte mode string,
+     1 24-byte time string (may be longer in some locales -- see below),
+     9 spaces, one following each of these fields, and
+     1 trailing NUL byte.  */
+  char init_bigbuf[7 * 20 + 10 + 24 + 9 + 1];
+  char *buf = init_bigbuf;
+  size_t bufsize = sizeof (init_bigbuf);
+  size_t s;
   char *p;
   time_t when;
+  const char *fmt;
 
 #ifdef HAVE_ST_DM_MODE
   mode_string (f->stat.st_dm_mode, modebuf);
@@ -2055,12 +2070,10 @@ print_long_format (const struct fileinfo *f)
       break;
     }
 
-  /* Use strftime rather than ctime, because the former can produce
-     locale-dependent names for the weekday (%a) and month (%b).  */
-  strftime (timebuf, TIMEBUF_SIZE, "%a %b %d %H:%M:%S %Y", localtime (&when));
-
   if (full_time)
-    timebuf[24] = '\0';
+    {
+      fmt = "%a %b %d %H:%M:%S %Y";
+    }
   else
     {
       if (current_time > when + 6L * 30L * 24L * 60L * 60L	/* Old. */
@@ -2072,12 +2085,15 @@ print_long_format (const struct fileinfo *f)
 	     Allow a 1 hour slop factor for what is considered "the future",
 	     to allow for NFS server/client clock disagreement.
 	     Show the year instead of the time of day.  */
-	  strcpy (timebuf + 11, timebuf + 19);
+	  fmt = "%b %e  %Y";
+	}
+      else
+	{
+	  fmt = "%b %e %H:%M";
 	}
-      timebuf[16] = 0;
     }
 
-  p = bigbuf;
+  p = buf;
 
   if (print_inode)
     {
@@ -2120,11 +2136,25 @@ print_long_format (const struct fileinfo *f)
     sprintf (p, "%8lu ", (unsigned long) f->stat.st_size);
   p += strlen (p);
 
-  sprintf (p, "%s ", full_time ? timebuf : timebuf + 4);
-  p += strlen (p);
+  /* Use strftime rather than ctime, because the former can produce
+     locale-dependent names for the weekday (%a) and month (%b).  */
+
+  while (! (s = strftime (p, buf + bufsize - p, fmt, localtime (&when))))
+    {
+      char *newbuf = (char *) alloca (bufsize *= 2);
+      memcpy (newbuf, buf, p - buf);
+      p = newbuf + (p - buf);
+      buf = newbuf;
+    }
+
+  p += s;
+  *p++ = ' ';
+
+  /* NUL-terminate the string -- fputs (via FPUTS) requires it.  */
+  *p = '\0';
 
   DIRED_INDENT ();
-  FPUTS (bigbuf, stdout, p - bigbuf);
+  FPUTS (buf, stdout, p - buf);
   PUSH_CURRENT_DIRED_POS (&dired_obstack);
   print_name_with_quoting (f->name, f->stat.st_mode, f->linkok);
   PUSH_CURRENT_DIRED_POS (&dired_obstack);
@@ -2134,7 +2164,7 @@ print_long_format (const struct fileinfo *f)
       if (f->linkname)
 	{
 	  FPUTS_LITERAL (" -> ", stdout);
-	  print_name_with_quoting (f->linkname, f->linkmode, f->linkok-1);
+	  print_name_with_quoting (f->linkname, f->linkmode, f->linkok - 1);
 	  if (indicator_style != none)
 	    print_type_indicator (f->linkmode);
 	}
@@ -2297,15 +2327,19 @@ print_name_with_quoting (const char *p, unsigned int mode, int linkok)
     free (quoted);
 
   if (print_with_color)
+    prep_non_filename_text ();
+}
+
+static void
+prep_non_filename_text (void)
+{
+  if (color_indicator[C_END].string != NULL)
+    put_indicator (&color_indicator[C_END]);
+  else
     {
-      if (color_indicator[C_END].string != NULL)
-	put_indicator (&color_indicator[C_END]);
-      else
-	{
-	  put_indicator (&color_indicator[C_LEFT]);
-	  put_indicator (&color_indicator[C_NORM]);
-	  put_indicator (&color_indicator[C_RIGHT]);
-	}
+      put_indicator (&color_indicator[C_LEFT]);
+      put_indicator (&color_indicator[C_NORM]);
+      put_indicator (&color_indicator[C_RIGHT]);
     }
 }
 
