@@ -63,7 +63,9 @@ Create named pipes (FIFOs) with the given NAMEs.\n\
 \n\
   -m, --mode=MODE   set permission mode (as in chmod), not 0666 - umask\n\
       --help        display this help and exit\n\
-      --version     output version information and exit\n"));
+      --version     output version information and exit\n\
+"));
+      puts (_("\nReport bugs to fileutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status);
 }
@@ -104,7 +106,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("mkfifo - %s\n", PACKAGE_VERSION);
+      printf ("mkfifo (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (0);
     }
 
