@@ -74,7 +74,9 @@ MAJOR MINOR are forbidden for TYPE p, mandatory otherwise.  TYPE may be:\n\
 \n\
   b      create a block (buffered) special file\n\
   c, u   create a character (unbuffered) special file\n\
-  p      create a FIFO\n"));
+  p      create a FIFO\n\
+"));
+      puts (_("\nReport bugs to fileutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status);
 }
@@ -113,7 +115,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("mknod - %s\n", PACKAGE_VERSION);
+      printf ("mknod (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (0);
     }
 
