@@ -157,7 +157,7 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("rm - %s\n", PACKAGE_VERSION);
+      printf ("rm (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (0);
     }
 
@@ -535,10 +535,12 @@ Remove (unlink) the FILE(s).\n\
   -d, --directory       unlink directory, even if non-empty (super-user only)\n\
   -f, --force           ignore nonexistent files, never prompt\n\
   -i, --interactive     prompt before any removal\n\
-  -v, --verbose         explain what is being done\n\
   -r, -R, --recursive   remove the contents of directories recursively\n\
+  -v, --verbose         explain what is being done\n\
       --help            display this help and exit\n\
-      --version         output version information and exit\n"));
+      --version         output version information and exit\n\
+"));
+      puts (_("\nReport bugs to fileutils-bugs@gnu.ai.mit.edu"));
     }
   exit (status);
 }
